// Original: http://www.forexfactory.com/showpost.php?p=4165384&postcount=41

#include <mt4R.mqh>

//    Rterm.exe: "c:\Program Files\R\R-2.12.1\bin\x64\Rterm.exe".
//        .
//      " --no-save".
#define RPATH "c:/Program Files/R/R-2.12.1/bin/x64/Rterm.exe --no-save"
#define RDEBUG 1  // debug level (0: none, 1: warnings, 2:all)

string symb[] = {"AUDUSD", "EURUSD", "GBPUSD", "NZDUSD", "USDCAD", "USDCHF", "USDJPY"};
extern int back = 500;      // how many bars back
extern int plot_alpha = 50; // transparency of plotted points [0..255], 0=transparent

int last_bar_time;          // needed for detecting a new bar
int last_back_line_time;    // optional vertical line moved by user to override the back value

// start and initialize the R engine
int init(){
   if (UninitializeReason() != REASON_CHARTCHANGE){
      StartR(RPATH, RDEBUG);
      Rx("options(device='windows')");
   }
   last_bar_time = 0;
}

// stop the R engine
int deinit(){
   if (UninitializeReason() != REASON_CHARTCHANGE){
      StopR();
   }
}

// a new tick has arrived
int start(){
   int nrow, ncol;
   int i, j, ishift;
   int back_line_time;
   double matrix[]; // this actually represents the flattened data of a 2d array

   // optional: the user might have drawn a vertical line named "back"
   // this will override the value of back, otherwise this code does nothing
   back_line_time = ObjectGet("back", OBJPROP_TIME1);
   if (back_line_time != 0){
      if (back_line_time != last_back_line_time){
         last_back_line_time = back_line_time;
         last_bar_time = 0; // force a new bar when the user moved the line
      }
      back = iBarShift(NULL, 0, back_line_time);
   }

   // not a new bar? --> exit
   if (last_bar_time == Time[0]) return(0);
   last_bar_time = Time[0];


   // we have reached this point because there was either a new
   // bar or the user moved the back line and we make a new plot now


   // create the matrix of past prices,
   // each row is a bar, each column is a currency pair.
   ncol = ArraySize(symb);
   nrow = back;
   ArrayResize(matrix, nrow * ncol);
   for (i=nrow-1; i>=0; i--){
      for (j=0; j<ncol; j++){
         ishift = iBarShift(symb[j], 0, Time[i]);
         matrix[i * ncol + j] = iClose(symb[j], 0, ishift);
      }
   }

   // assign the data to the matrix "currencies"
   Rm("currencies", matrix, nrow, ncol);

   // assign the column names
   Rf("names", symb);
   Rx("colnames(currencies) <- names");

   // make a pairs plot. the points are semi-transparent (plot_alpha)
   Ri("plot_alpha", plot_alpha);
   Rx("pairs(currencies, gap=0, col=rgb(0,0,0,plot_alpha,maxColorValue=255))");

}